@@ -1,5 +1,3 @@
-/* $Id: uptime.c,v 1.21 2004/07/03 13:28:59 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -24,15 +22,20 @@
 #include <config.h>
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
+
+#include "glibtop_private.h"
+
 #include <time.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
+  (1UL << GLIBTOP_UPTIME_UPTIME) \
++ (1UL << GLIBTOP_UPTIME_IDLETIME) \
++ (1UL << GLIBTOP_UPTIME_BOOT_TIME);
 
 /* Init function. */
 
 void
-glibtop_init_uptime_s (glibtop *server)
+_glibtop_init_uptime_s (glibtop *server)
 {
 	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
@@ -52,9 +55,9 @@ glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 
 	file_to_buffer(server, buffer, FILENAME);
 
-	buf->uptime   = strtod (buffer, &p);
-	buf->idletime = strtod (p, &p);
-	buf->boot_time = (guint64) time(NULL) - (guint64) buf->uptime;
+	buf->uptime   = g_ascii_strtod (buffer, &p);
+	buf->idletime = g_ascii_strtod (p, &p);
+	buf->boot_time = get_boot_time(server);
 
 	buf->flags = _glibtop_sysdeps_uptime;
 }
