@@ -1,7 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -34,7 +30,7 @@
 #undef user
 #undef idle
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 int table (int id, int index, char *addr, int nel, u_int lel);
 
@@ -42,11 +38,11 @@ typedef struct _glibtop_machine		glibtop_machine;
 
 struct _glibtop_machine
 {
-    uid_t uid, euid;		/* Real and effective user id */
-    gid_t gid, egid;		/* Real and effective group id */
-    unsigned proctable_entries;	/* Max entries in the proctable */
+	uid_t uid, euid;		/* Real and effective user id */
+	gid_t gid, egid;		/* Real and effective group id */
+	unsigned proctable_entries;	/* Max entries in the proctable */
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
